@@ -15,11 +15,11 @@ WebService::Careerjet - Perl interface to Careerjet's public search API
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06' ;
 
 =head1 SYNOPSIS
 
@@ -79,13 +79,15 @@ Usage:
 Available locales:
 
     LOCALE     LANGUAGE         DEFAULT LOCATION     CAREERJET SITE
-    cz_CZ      Czech Republic   Czech                http://www.careerjet.cz
+    cs_CZ      Czech            Czech Republic       http://www.careerjet.cz
     da_DK      Danish           Denmark              http://www.careerjet.dk
     de_AT      German           Austria              http://www.careerjet.at
     de_CH      German           Switzerland          http://www.careerjet.ch
     de_DE      German           Germany              http://www.careerjet.de
+    en_AE      English          United Arab Emirates http://www.careerjet.ae
     en_AU      English          Australia            http://www.careerjet.com.au
-    en_CN      English          China                http://www.careerjet.cn
+    en_CA      English          Canada               http://www.careerjet.ca
+    en_CN      English          China                http://en.careerjet.cn
     en_HK      English          Hong Kong            http://www.careerjet.hk
     en_IE      English          Ireland              http://www.careerjet.ie
     en_IN      English          India                http://www.careerjet.co.in
@@ -96,15 +98,31 @@ Available locales:
     en_US      English          United States        http://www.careerjet.com
     en_ZA      English          South Africa         http://www.careerjet.co.za
     en_TW      English          Taiwan               http://www.careerjet.com.tw
+    es_AR      Spanish          Argentina            http://www.opcionempleo.com.ar
+    es_BO      Spanish          Bolivia              http://www.opcionempleo.com.bo
+    es_CL      Spanish          Chile                http://www.opcionempleo.cl
+    es_CR      Spanish          Costa Rica           http://www.opcionempleo.co.cr
+    es_DO      Spanish          Dominican Republic   http://www.opcionempleo.com.do
+    es_EC      Spanish          Ecuador              http://www.opcionempleo.ec
     es_ES      Spanish          Spain                http://www.opcionempleo.com
+    es_GT      Spanish          Guatemala            http://www.opcionempleo.com.gt
     es_MX      Spanish          Mexico               http://www.opcionempleo.com.mx
+    es_PA      Spanish          Panama               http://www.opcionempleo.com.pa
+    es_PE      Spanish          Peru                 http://www.opcionempleo.com.pe
+    es_PR      Spanish          Puerto Rico          http://www.opcionempleo.com.pr
+    es_PY      Spanish          Paraguay             http://www.opcionempleo.com.py
+    es_UY      Spanish          Uruguay              http://www.opcionempleo.com.uy
+    es_VE      Spanish          Venezuela            http://www.opcionempleo.com.ve
     fi_FI      Finnish          Finland              http://www.careerjet.fi
+    fr_CA      French           Canada               http://fr.careerjet.ca
     fr_BE      French           Belgium              http://www.optioncarriere.be
     fr_CH      French           Switzerland          http://www.optioncarriere.ch
     fr_FR      French           France               http://www.optioncarriere.com
     fr_LU      French           Luxembourg           http://www.optioncarriere.lu
     fr_MA      French           Morocco              http://www.optioncarriere.ma
     it_IT      Italian          Italy                http://www.careerjet.it
+    ja_JP      Japanese         Japan                http://www.careerjet.jp
+    ko_KR      Korean           Korea                http://www.careerjet.co.kr
     nl_BE      Dutch            Belgium              http://www.careerjet.be
     nl_NL      Dutch            Netherlands          http://www.careerjet.nl
     no_NO      Norwegian        Norway               http://www.careerjet.no
@@ -113,17 +131,21 @@ Available locales:
     pt_BR      Portuguese       Brazil               http://www.careerjet.com.br
     sv_SE      Swedish          Sweden               http://www.careerjet.se
     sk_SK      Slovak           Slovakia             http://www.careerjet.sk
+    tr_TR      Turkish          Turkey               http://www.careerjet.com.tr
+    zh_CN      Chinese          China                http://www.careerjet.cn
 
 =cut
    
 my %h_locale2base = ( 
-    cz_CZ  => "http://www.careerjet.cz",
+    cs_CZ  => "http://www.careerjet.cz",
     da_DK  => "http://www.careerjet.dk",
     de_AT  => "http://www.careerjet.at",
     de_CH  => "http://www.careerjet.ch",
     de_DE  => "http://www.careerjet.de",
+    en_AE  => "http://www.careerjet.ae",
     en_AU  => "http://www.careerjet.com.au",
-    en_CN  => "http://www.careerjet.cn",
+    en_CA  => "http://www.careerjet.ca/",
+    en_CN  => "http://en.careerjet.cn",
     en_HK  => "http://www.careerjet.hk",
     en_IE  => "http://www.careerjet.ie",
     en_IN  => "http://www.careerjet.co.in",
@@ -135,15 +157,31 @@ my %h_locale2base = (
     en_US  => "http://www.careerjet.com",
     en_ZA  => "http://www.careerjet.co.za",
     en_TW  => "http://www.careerjet.com.tw",
+    es_AR  => "http://www.opcionempleo.com.ar",
+    es_BO  => "http://www.opcionempleo.com.bo",
+    es_CL  => "http://www.opcionempleo.cl",
+    es_CR  => "http://www.opcionempleo.co.cr",
+    es_DO  => "http://www.opcionempleo.com.do",
+    es_EC  => "http://www.opcionempleo.ec",
     es_ES  => "http://www.opcionempleo.com",
+    es_GT  => "http://www.opcionempleo.com.gt" ,
     es_MX  => "http://www.opcionempleo.com.mx",
+    es_PA  => "http://www.opcionempleo.com.pa",
+    es_PE  => "http://www.opcionempleo.com.pe",
+    es_PR  => "http://www.opcionempleo.com.pr",
+    es_PY  => "http://www.opcionempleo.com.py",
+    es_UY  => "http://www.opcionempleo.com.uy",
+    es_VE  => "http://www.opcionempleo.com.ve",
     fi_FI  => "http://www.careerjet.fi",
     fr_BE  => "http://www.optioncarriere.be",
+    fr_CA  => "http://fr.careerjet.ca" ,
     fr_CH  => "http://www.optioncarriere.ch",
     fr_FR  => "http://www.optioncarriere.com",
     fr_LU  => "http://www.optioncarriere.lu",
     fr_MA  => "http://www.optioncarriere.ma",
     it_IT  => "http://www.careerjet.it",
+    ja_JP  => "http://www.careerjet.jp",
+    ko_KR  => "http://www.careerjet.co.kr",
     nl_BE  => "http://www.careerjet.be",
     nl_NL  => "http://www.careerjet.nl",
     no_NO  => "http://www.careerjet.no",
@@ -152,6 +190,8 @@ my %h_locale2base = (
     pt_BR  => "http://www.careerjet.com.br",
     sv_SE  => "http://www.careerjet.se",
     sk_SK  => "http://www.careerjet.sk",
+    tr_TR  => "http://www.careerjet.com.tr",
+    zh_CN  => "http://www.careerjet.cn",
 );
 
 
